@@ -18,7 +18,7 @@ class QueryCustomerUnitTestCase(unittest.TestCase):
         assert response.data == b'ping'
        
     def test_query_registered_customer_by_year_month(self):
-        response = app.test_client().get('/biqquery/customer/registered-customer-by-year-month', json={'year_month_from': 202101, 'year_month_to': 202112})
+        response = app.test_client().get('/biqquery/customer/registered-customer-by-year-month', json={'date_range_from': 202101, 'date_range_to': 202112})
         
         logger.debug('response=%s', response)
 
