@@ -122,7 +122,6 @@ def import_registered_merchant_function(dataset_name='system', limit=analytics_c
         
     
     merchant_data_dict_to_stream = {'':merchant_acct_dict_list}
-    errors = []
     logger.debug('################################ batch_id= %s ############################################', batch_id)
     logger.debug(merchant_data_dict_to_stream)
     logger.debug('#####################################################################################################')
@@ -133,6 +132,8 @@ def import_registered_merchant_function(dataset_name='system', limit=analytics_c
                                                partition_year=True
                          )
     
+    bg_client.close()
+    
     if errors==[]:
         logger.debug("New rows have been added")
     else:
